@@ -316,6 +316,9 @@ def __setup_logger(verbose: bool):
 
   logger.addHandler(ch)
 
+  if verbose:
+    print("log file location: "+filepath)
+
 def __iq_control_flow(args: dict, bom_str: bytes):
   with yaspin(text="Loading", color="magenta") as spinner:
     spinner.text = "Submitting to Sonatype IQ..."
@@ -339,6 +342,14 @@ def __iq_control_flow(args: dict, bom_str: bytes):
       print(Fore.YELLOW +
             "Your IQ Server Report is available here: {}".format(iq_requests.get_report_url()))
       _exit(1)
+    elif iq_requests.get_policy_action() == 'Warning':
+      spinner.ok("🧨 ")
+      __toggle_stdout(on=True)
+      print(Fore.GREEN +
+            "Something slithers around your ankle! There are policy warnings from Sonatype IQ.")
+      print(Fore.GREEN +
+            "Your IQ Server Report is available here: {}".format(iq_requests.get_report_url()))
+      _exit(0)
     elif iq_requests.get_policy_action() == 'None':
       spinner.ok("🐍 ")
       __toggle_stdout(on=True)
@@ -351,7 +362,8 @@ def __iq_control_flow(args: dict, bom_str: bytes):
       spinner.fail("🐍 ")
       __toggle_stdout(on=True)
       print(Fore.RED +
-            "Received an error response from IQ Server, please check logs.")
+            "Received an error response from IQ Server, please check logs. policy action: {}"
+            .format(iq_requests.get_policy_action()))
       _exit(3)
 
 def __sbom_control_flow(conda: bool, target: str) -> (bytes):
